package collision;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Polygon;
import java.awt.geom.Point2D;
import java.util.ArrayList;

public abstract class GameObject {

	String name = "UNDEFINED";		// unique name
	protected int x = 0;			// current position
	protected int y = 0;

	protected GameState gameState;	// the game state
	
	protected ArrayList<Point> polygonCoords;		// will be drawn at position
	
	public GameObject(String name, int x, int y, GameState gameState) {
		this.name = name;
		this.x = x;
		this.y = y;
		this.gameState = gameState;
		
		if (this.name != null) {	// init the polygon
			this.polygonCoords = PolygonUtils.readFromFile(name);
		}
	}

	public String getName() { return name; }	// 	getters
	public int getX() { return x; }
	public int getY() { return y; }

	public Polygon getPolygon() {
		Polygon poly = new Polygon();
		if (polygonCoords != null) {
			for (Point2D point : polygonCoords) {
				poly.addPoint((int)point.getX() + x, (int)point.getY() + y);
			}
		}
		return poly;
	}

	public abstract void draw(Graphics2D g);
	
}