package collision;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;

import javax.swing.JPanel;

public class GamePanel extends JPanel implements Runnable {

	public static final int NUM_STATIC_OBJECTS = 500;
	
	public static final int PWIDTH = 500; // size of panel
	public static final int PHEIGHT = 400;

	private Thread animator; // the thread that performs the animation

	private volatile boolean running = false; // used to stop the animation thread

	public static Font font = new Font("SansSerif", Font.BOLD, 14); // set up message font to display text
	private String title = "Collission Detection"; // status string displayed on top of page
	
	// holds all movable + static objects of the game
	GameState gameState;
	
	public GamePanel() {
		setBackground(Color.white);
		setPreferredSize(new Dimension(PWIDTH, PHEIGHT));
		setFocusable(true);
		requestFocus(); 
		registerKeyListeners();	
	}

	public void addNotify() {
		super.addNotify();
		startGame();
	}

	private void startGame() {
		initGame();
		if (animator == null || !running) {
			animator = new Thread(this);
			animator.start();
		}
	}

	private void initGame() {
		// create game objects and add to state
		gameState = new GameState();

		MovingObject mo1 = new MovingObject("movingobject",PWIDTH-50,PHEIGHT-50,gameState);
		gameState.setPlayer(mo1);

		List<GameObject> staticObjects = new ArrayList<GameObject>();
		for (int i=0; i<NUM_STATIC_OBJECTS; i++) {	// create 50 static objects
			staticObjects.add(createStaticObject(gameState));
		}
		gameState.setStaticObjects(staticObjects);
	}
	
	private StaticObject createStaticObject(GameState gameState) {	// create 1 static object at random position
		Random r = new Random();
		int randint;
		int spacing = 50;
		randint = r.nextInt((PWIDTH / spacing) - 1);
		int x = randint*spacing;
		randint = r.nextInt((PHEIGHT / spacing) - 1);
		int y = randint*spacing;
		randint = r.nextInt(3);
		int num = randint + 1;
		StaticObject o = new StaticObject("staticobject" + num, x, y, gameState);
		return o;
	}
	
	public void run() {
		running = true;
		while (running) {
			gameUpdate();
			repaint();
		}
		System.exit(0);
	}

    public void paintComponent(Graphics g) {
        Graphics2D g2 = (Graphics2D) g;
        if (running) paintGame(g2);
    }

    private void paintGame(Graphics2D g) {
		g.setColor(Color.white);
		g.fillRect(0, 0, PWIDTH, PHEIGHT);
    	gameState.draw(g); // draw the game objects
		g.setColor(Color.blue);
		g.setFont(font);
		g.drawString(title, 20, 25);		
    }
    
    
	private void gameUpdate() {
		gameState.update();
	}

	private void registerKeyListeners() {
		addKeyListener(new KeyAdapter() {
			public void keyPressed(KeyEvent e) {
				int keyCode = e.getKeyCode();
				if ((keyCode == KeyEvent.VK_ESCAPE)
						|| ((keyCode == KeyEvent.VK_C) && e.isControlDown())) {
					running = false;
				} else if (keyCode == KeyEvent.VK_LEFT) {
					gameState.setXYDirection(-1,0);
				} else if (keyCode == KeyEvent.VK_RIGHT) {
					gameState.setXYDirection(1,0);
				} else if (keyCode == KeyEvent.VK_DOWN) {
					gameState.setXYDirection(0,1);
				} else if (keyCode == KeyEvent.VK_UP) {
					gameState.setXYDirection(0,-1);
				}
			}
		});
	}
	
	// ------------- game life cycle methods ------------
	// called by the JFrame's window listener methods

	public void stopGame() {
		running = false;
	}

	// ----------------------------------------------

} // end of WormPanel class
