package collision;
import java.awt.Color;
import java.awt.Graphics2D;

public class MovingObject extends GameObject {
	
	private int xDirection = 0;		// current movement
	private int yDirection = 0;
	private int movePixels = 5;		// move per cycle
	private boolean collision = false; // indicates colliding objects

	long t1 = 0; // measures duration of collision detection
	
	public MovingObject(String name, int x, int y, GameState gameState) {
		super(name, x, y, gameState);
	}

	public void setXYDirection(int xDirection, int yDirection) {
		this.xDirection = xDirection;
		this.yDirection = yDirection;
	}

	public void update() {
		x = x + (xDirection*movePixels);	
		y = y + (yDirection*movePixels);
		if (x > GamePanel.PWIDTH || x < 0) xDirection *= -1; 
		if (y > GamePanel.PHEIGHT || y < 0) yDirection *= -1;	
		xDirection = 0;
		yDirection = 0;
		long t = System.nanoTime();
		boolean collisionDetected = false;
		for (GameObject o : gameState.getStaticObjects()) {
			if (o.getPolygon() != null) { 
				if (CollisionDetector.detect(getPolygon(), o.getPolygon())) {
					collisionDetected = true;
				}
			}
		}
		t1 = System.nanoTime() - t;
		collision = collisionDetected;
	}
	
	public void draw(Graphics2D g) {
		g.setColor(Color.blue);
		g.fillPolygon(getPolygon());	
		g.setColor(Color.blue);
		g.setFont(GamePanel.font);
		g.drawString("Collision detected: " + collision + 
				" - operation took " + t1/1000 + "micros", 25, GamePanel.PHEIGHT-25);	
	}

}